netapp_ontap.models.storage_switch_connections_peer_port API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_switch_connections_peer_port`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageSwitchConnectionsPeerPortSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageSwitchConnectionsPeerPort object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `connection: str GET POST PATCH`

    Storage switch peer port host and name

  `type: str GET POST PATCH`

    Storage switch peer type

    Valid choices:

    - unknown
    - bridge
    - switch
    - fcp_adapter
    - fcvi_adapter
  `unique_id: str GET POST PATCH`

    Storage switch peer unique ID

  `wwn: str GET POST PATCH`

    Storage switch peer port world wide name